# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# Analytics Game Telemetry

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from .utils import randomize

from ..api.gametelemetry.models import BaseErrorResponse
from ..api.gametelemetry.models import GetNamespaceEventResponse
from ..api.gametelemetry.models import HTTPValidationError
from ..api.gametelemetry.models import ListBaseResponseStr
from ..api.gametelemetry.models import PagedResponseGetNamespaceEventResponse
from ..api.gametelemetry.models import Paging
from ..api.gametelemetry.models import PlayTimeResponse
from ..api.gametelemetry.models import TelemetryBody
from ..api.gametelemetry.models import ValidationError


def create_base_error_response_example() -> BaseErrorResponse:
    instance = BaseErrorResponse()
    instance.error_code = randomize("int", min_val=1, max_val=1000)
    instance.error_message = randomize()
    return instance


def create_get_namespace_event_response_example() -> GetNamespaceEventResponse:
    instance = GetNamespaceEventResponse()
    instance.event_id = randomize()
    instance.event_name = randomize()
    instance.event_namespace = randomize("slug")
    instance.event_timestamp = randomize()
    instance.flight_id = randomize()
    instance.payload = {randomize(): randomize()}
    instance.user_id = randomize("uid")
    instance.user_namespace = randomize("slug")
    return instance


def create_http_validation_error_example() -> HTTPValidationError:
    instance = HTTPValidationError()
    instance.detail = [create_validation_error_example()]
    return instance


def create_list_base_response_str_example() -> ListBaseResponseStr:
    instance = ListBaseResponseStr()
    instance.data = [randomize()]
    return instance


def create_paged_response_get_namespace_event_response_example() -> (
    PagedResponseGetNamespaceEventResponse
):
    instance = PagedResponseGetNamespaceEventResponse()
    instance.data = [create_get_namespace_event_response_example()]
    instance.paging = create_paging_example()
    return instance


def create_paging_example() -> Paging:
    instance = Paging()
    instance.next_ = randomize()
    instance.previous = randomize()
    return instance


def create_play_time_response_example() -> PlayTimeResponse:
    instance = PlayTimeResponse()
    instance.total_playtime = randomize("int", min_val=1, max_val=1000)
    return instance


def create_telemetry_body_example() -> TelemetryBody:
    instance = TelemetryBody()
    instance.event_name = randomize()
    instance.event_namespace = randomize("slug")
    instance.payload = {randomize(): randomize()}
    instance.client_timestamp = randomize("date")
    instance.device_type = randomize()
    instance.event_id = randomize()
    instance.event_timestamp = randomize("date")
    return instance


def create_validation_error_example() -> ValidationError:
    instance = ValidationError()
    instance.loc = [randomize()]
    instance.msg = randomize()
    instance.type_ = randomize()
    return instance



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Platform Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model


class WxPayConfigInfo(Model):
    """A DTO object for wxpay config. (WxPayConfigInfo)

    Properties:
        app_id: (appId) OPTIONAL str

        cert_path: (certPath) OPTIONAL str

        key: (key) OPTIONAL str

        mchid: (mchid) OPTIONAL str

        return_url: (returnUrl) OPTIONAL str
    """

    # region fields

    app_id: str  # OPTIONAL
    cert_path: str  # OPTIONAL
    key: str  # OPTIONAL
    mchid: str  # OPTIONAL
    return_url: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_app_id(self, value: str) -> WxPayConfigInfo:
        self.app_id = value
        return self

    def with_cert_path(self, value: str) -> WxPayConfigInfo:
        self.cert_path = value
        return self

    def with_key(self, value: str) -> WxPayConfigInfo:
        self.key = value
        return self

    def with_mchid(self, value: str) -> WxPayConfigInfo:
        self.mchid = value
        return self

    def with_return_url(self, value: str) -> WxPayConfigInfo:
        self.return_url = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "app_id"):
            result["appId"] = str(self.app_id)
        elif include_empty:
            result["appId"] = ""
        if hasattr(self, "cert_path"):
            result["certPath"] = str(self.cert_path)
        elif include_empty:
            result["certPath"] = ""
        if hasattr(self, "key"):
            result["key"] = str(self.key)
        elif include_empty:
            result["key"] = ""
        if hasattr(self, "mchid"):
            result["mchid"] = str(self.mchid)
        elif include_empty:
            result["mchid"] = ""
        if hasattr(self, "return_url"):
            result["returnUrl"] = str(self.return_url)
        elif include_empty:
            result["returnUrl"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        app_id: Optional[str] = None,
        cert_path: Optional[str] = None,
        key: Optional[str] = None,
        mchid: Optional[str] = None,
        return_url: Optional[str] = None,
        **kwargs,
    ) -> WxPayConfigInfo:
        instance = cls()
        if app_id is not None:
            instance.app_id = app_id
        if cert_path is not None:
            instance.cert_path = cert_path
        if key is not None:
            instance.key = key
        if mchid is not None:
            instance.mchid = mchid
        if return_url is not None:
            instance.return_url = return_url
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> WxPayConfigInfo:
        instance = cls()
        if not dict_:
            return instance
        if "appId" in dict_ and dict_["appId"] is not None:
            instance.app_id = str(dict_["appId"])
        elif include_empty:
            instance.app_id = ""
        if "certPath" in dict_ and dict_["certPath"] is not None:
            instance.cert_path = str(dict_["certPath"])
        elif include_empty:
            instance.cert_path = ""
        if "key" in dict_ and dict_["key"] is not None:
            instance.key = str(dict_["key"])
        elif include_empty:
            instance.key = ""
        if "mchid" in dict_ and dict_["mchid"] is not None:
            instance.mchid = str(dict_["mchid"])
        elif include_empty:
            instance.mchid = ""
        if "returnUrl" in dict_ and dict_["returnUrl"] is not None:
            instance.return_url = str(dict_["returnUrl"])
        elif include_empty:
            instance.return_url = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, WxPayConfigInfo]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[WxPayConfigInfo]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[WxPayConfigInfo, List[WxPayConfigInfo], Dict[Any, WxPayConfigInfo]]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "appId": "app_id",
            "certPath": "cert_path",
            "key": "key",
            "mchid": "mchid",
            "returnUrl": "return_url",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "appId": False,
            "certPath": False,
            "key": False,
            "mchid": False,
            "returnUrl": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Challenge Service."""

__version__ = "1.11.1"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .admin_create_assignment_plugin import AdminCreateAssignmentPlugin
from .admin_delete_assignment_plugin import AdminDeleteAssignmentPlugin
from .admin_get_assignment_plugin import AdminGetAssignmentPlugin
from .admin_update_assignment_plugin import AdminUpdateAssignmentPlugin



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ErrorEntity
from ..models import UpdatePolicyRequest

from ..operations.policies_with_namespace import DeletePolicy
from ..operations.policies_with_namespace import SetDefaultPolicy3
from ..operations.policies_with_namespace import UpdatePolicy1


@same_doc_as(DeletePolicy)
def delete_policy(
    policy_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete Policy (deletePolicy)

    Delete policy.Can only be deleted if match these criteria:


      * Policy is not default policy
      * Policy version under policy has never been accepted by any user

    Properties:
        url: /agreement/admin/namespaces/{namespace}/policies/{policyId}

        method: DELETE

        tags: ["Policies With Namespace"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        policy_id: (policyId) REQUIRED str in path

    Responses:
        204: No Content - (Successful operation)

        400: Bad Request - ErrorEntity (40033: errors.net.accelbyte.platform.legal.invalid_policy_id | 40072: errors.net.accelbyte.platform.legal.policy_have_published_policy_version | 40073: errors.net.accelbyte.platform.legal.policy_have_published_policy_version_and_already_accepted_by_user | 40074: errors.net.accelbyte.platform.legal.policy_is_default_policy)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeletePolicy.create(
        policy_id=policy_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(DeletePolicy)
async def delete_policy_async(
    policy_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete Policy (deletePolicy)

    Delete policy.Can only be deleted if match these criteria:


      * Policy is not default policy
      * Policy version under policy has never been accepted by any user

    Properties:
        url: /agreement/admin/namespaces/{namespace}/policies/{policyId}

        method: DELETE

        tags: ["Policies With Namespace"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        policy_id: (policyId) REQUIRED str in path

    Responses:
        204: No Content - (Successful operation)

        400: Bad Request - ErrorEntity (40033: errors.net.accelbyte.platform.legal.invalid_policy_id | 40072: errors.net.accelbyte.platform.legal.policy_have_published_policy_version | 40073: errors.net.accelbyte.platform.legal.policy_have_published_policy_version_and_already_accepted_by_user | 40074: errors.net.accelbyte.platform.legal.policy_is_default_policy)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeletePolicy.create(
        policy_id=policy_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(SetDefaultPolicy3)
def set_default_policy_3(
    policy_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Set Default Policy (setDefaultPolicy_3)

    Update a policy to be the default.

    Properties:
        url: /agreement/admin/namespaces/{namespace}/policies/{policyId}/default

        method: PATCH

        tags: ["Policies With Namespace"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        policy_id: (policyId) REQUIRED str in path

    Responses:
        200: OK - (operation successful)

        400: Bad Request - ErrorEntity (40033: errors.net.accelbyte.platform.legal.invalid_policy_id)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = SetDefaultPolicy3.create(
        policy_id=policy_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(SetDefaultPolicy3)
async def set_default_policy_3_async(
    policy_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Set Default Policy (setDefaultPolicy_3)

    Update a policy to be the default.

    Properties:
        url: /agreement/admin/namespaces/{namespace}/policies/{policyId}/default

        method: PATCH

        tags: ["Policies With Namespace"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        policy_id: (policyId) REQUIRED str in path

    Responses:
        200: OK - (operation successful)

        400: Bad Request - ErrorEntity (40033: errors.net.accelbyte.platform.legal.invalid_policy_id)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = SetDefaultPolicy3.create(
        policy_id=policy_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UpdatePolicy1)
def update_policy_1(
    policy_id: str,
    body: Optional[UpdatePolicyRequest] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update Country-Specific Policy (updatePolicy_1)

    Update country-specific and country-group policy.

    Properties:
        url: /agreement/admin/namespaces/{namespace}/policies/{policyId}

        method: PATCH

        tags: ["Policies With Namespace"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL UpdatePolicyRequest in body

        namespace: (namespace) REQUIRED str in path

        policy_id: (policyId) REQUIRED str in path

    Responses:
        200: OK - (operation successful)

        400: Bad Request - ErrorEntity (40033: errors.net.accelbyte.platform.legal.invalid_policy_id)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UpdatePolicy1.create(
        policy_id=policy_id,
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UpdatePolicy1)
async def update_policy_1_async(
    policy_id: str,
    body: Optional[UpdatePolicyRequest] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update Country-Specific Policy (updatePolicy_1)

    Update country-specific and country-group policy.

    Properties:
        url: /agreement/admin/namespaces/{namespace}/policies/{policyId}

        method: PATCH

        tags: ["Policies With Namespace"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL UpdatePolicyRequest in body

        namespace: (namespace) REQUIRED str in path

        policy_id: (policyId) REQUIRED str in path

    Responses:
        200: OK - (operation successful)

        400: Bad Request - ErrorEntity (40033: errors.net.accelbyte.platform.legal.invalid_policy_id)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UpdatePolicy1.create(
        policy_id=policy_id,
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import deprecated
from ....core import same_doc_as

from ..models import ErrorEntity
from ..models import SlotInfo
from ..models import SlotMetadataUpdate

from ..operations.slot import GetSlotData
from ..operations.slot import GetUserNamespaceSlots
from ..operations.slot import PublicCreateUserNamespaceSlot
from ..operations.slot import PublicDeleteUserNamespaceSlot
from ..operations.slot import PublicGetSlotData
from ..operations.slot import PublicGetUserNamespaceSlots
from ..operations.slot import PublicUpdateUserNamespaceSlot
from ..operations.slot import PublicUpdateUserNamespaceSlotMetadata


@deprecated
@same_doc_as(GetSlotData)
def get_slot_data(
    slot_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Returns slot data (getSlotData)

    ## The endpoint is going to be deprecated


    Get slot data.
    Other detail info:

      *  Returns : slot data

    Properties:
        url: /social/admin/namespaces/{namespace}/users/{userId}/slots/{slotId}

        method: GET

        tags: ["Slot"]

        consumes: []

        produces: ["application/octet-stream"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        slot_id: (slotId) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - Any (Successful operation)

        404: Not Found - ErrorEntity (12141: Slot [{slotId}] not found in namespace [{namespace}])
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetSlotData.create(
        slot_id=slot_id,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@deprecated
@same_doc_as(GetSlotData)
async def get_slot_data_async(
    slot_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Returns slot data (getSlotData)

    ## The endpoint is going to be deprecated


    Get slot data.
    Other detail info:

      *  Returns : slot data

    Properties:
        url: /social/admin/namespaces/{namespace}/users/{userId}/slots/{slotId}

        method: GET

        tags: ["Slot"]

        consumes: []

        produces: ["application/octet-stream"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        slot_id: (slotId) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - Any (Successful operation)

        404: Not Found - ErrorEntity (12141: Slot [{slotId}] not found in namespace [{namespace}])
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetSlotData.create(
        slot_id=slot_id,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@deprecated
@same_doc_as(GetUserNamespaceSlots)
def get_user_namespace_slots(
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Returns list of slots for given user (getUserNamespaceSlots)

    ## The endpoint is going to be deprecated


    Get slots for a given user.
    Other detail info:

      *  Returns : list of slots

    Properties:
        url: /social/admin/namespaces/{namespace}/users/{userId}/slots

        method: GET

        tags: ["Slot"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - List[SlotInfo] (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetUserNamespaceSlots.create(
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@deprecated
@same_doc_as(GetUserNamespaceSlots)
async def get_user_namespace_slots_async(
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Returns list of slots for given user (getUserNamespaceSlots)

    ## The endpoint is going to be deprecated


    Get slots for a given user.
    Other detail info:

      *  Returns : list of slots

    Properties:
        url: /social/admin/namespaces/{namespace}/users/{userId}/slots

        method: GET

        tags: ["Slot"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - List[SlotInfo] (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetUserNamespaceSlots.create(
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@deprecated
@same_doc_as(PublicCreateUserNamespaceSlot)
def public_create_user_namespace_slot(
    user_id: str,
    checksum: Optional[str] = None,
    custom_attribute: Optional[str] = None,
    file: Optional[Any] = None,
    label: Optional[str] = None,
    tags: Optional[List[str]] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Creates a slot (publicCreateUserNamespaceSlot)

    ## The endpoint is going to be deprecated


    Creates a slot.
    Other detail info:

      *  Returns : created slot info

    Properties:
        url: /social/public/namespaces/{namespace}/users/{userId}/slots

        method: POST

        tags: ["Slot"]

        consumes: ["multipart/form-data"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        checksum: (checksum) OPTIONAL str in form_data

        custom_attribute: (customAttribute) OPTIONAL str in form_data

        file: (file) OPTIONAL Any in form_data

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        label: (label) OPTIONAL str in query

        tags: (tags) OPTIONAL List[str] in query

    Responses:
        201: Created - (Successful create of a slot)

        400: Bad Request - ErrorEntity (12121: Checksum mismatch for [{filename}] | 12122: [{filename}] exceeds the upload limit size of [{sizeLimit}] bytes)

        409: Conflict - ErrorEntity (12171: User [{userId}] exceed max slot count [{maxCount}] in namespace [{namespace}])
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicCreateUserNamespaceSlot.create(
        user_id=user_id,
        checksum=checksum,
        custom_attribute=custom_attribute,
        file=file,
        label=label,
        tags=tags,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@deprecated
@same_doc_as(PublicCreateUserNamespaceSlot)
async def public_create_user_namespace_slot_async(
    user_id: str,
    checksum: Optional[str] = None,
    custom_attribute: Optional[str] = None,
    file: Optional[Any] = None,
    label: Optional[str] = None,
    tags: Optional[List[str]] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Creates a slot (publicCreateUserNamespaceSlot)

    ## The endpoint is going to be deprecated


    Creates a slot.
    Other detail info:

      *  Returns : created slot info

    Properties:
        url: /social/public/namespaces/{namespace}/users/{userId}/slots

        method: POST

        tags: ["Slot"]

        consumes: ["multipart/form-data"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        checksum: (checksum) OPTIONAL str in form_data

        custom_attribute: (customAttribute) OPTIONAL str in form_data

        file: (file) OPTIONAL Any in form_data

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        label: (label) OPTIONAL str in query

        tags: (tags) OPTIONAL List[str] in query

    Responses:
        201: Created - (Successful create of a slot)

        400: Bad Request - ErrorEntity (12121: Checksum mismatch for [{filename}] | 12122: [{filename}] exceeds the upload limit size of [{sizeLimit}] bytes)

        409: Conflict - ErrorEntity (12171: User [{userId}] exceed max slot count [{maxCount}] in namespace [{namespace}])
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicCreateUserNamespaceSlot.create(
        user_id=user_id,
        checksum=checksum,
        custom_attribute=custom_attribute,
        file=file,
        label=label,
        tags=tags,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@deprecated
@same_doc_as(PublicDeleteUserNamespaceSlot)
def public_delete_user_namespace_slot(
    slot_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Deletes the slot (publicDeleteUserNamespaceSlot)

    ## The endpoint is going to be deprecated


    Deletes the slot.
    Other detail info:

    Properties:
        url: /social/public/namespaces/{namespace}/users/{userId}/slots/{slotId}

        method: DELETE

        tags: ["Slot"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        slot_id: (slotId) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (Successful delete of a slot)

        404: Not Found - ErrorEntity (12141: Slot [{slotId}] not found in namespace [{namespace}])
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicDeleteUserNamespaceSlot.create(
        slot_id=slot_id,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@deprecated
@same_doc_as(PublicDeleteUserNamespaceSlot)
async def public_delete_user_namespace_slot_async(
    slot_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Deletes the slot (publicDeleteUserNamespaceSlot)

    ## The endpoint is going to be deprecated


    Deletes the slot.
    Other detail info:

    Properties:
        url: /social/public/namespaces/{namespace}/users/{userId}/slots/{slotId}

        method: DELETE

        tags: ["Slot"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        slot_id: (slotId) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (Successful delete of a slot)

        404: Not Found - ErrorEntity (12141: Slot [{slotId}] not found in namespace [{namespace}])
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicDeleteUserNamespaceSlot.create(
        slot_id=slot_id,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@deprecated
@same_doc_as(PublicGetSlotData)
def public_get_slot_data(
    slot_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Returns slot data (publicGetSlotData)

    ## The endpoint is going to be deprecated


    Get slot data.
    Other detail info:

      *  Returns : slot data

    Properties:
        url: /social/public/namespaces/{namespace}/users/{userId}/slots/{slotId}

        method: GET

        tags: ["Slot"]

        consumes: []

        produces: ["application/octet-stream"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        slot_id: (slotId) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - Any (Successful operation)

        404: Not Found - ErrorEntity (12141: Slot [{slotId}] not found in namespace [{namespace}])
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicGetSlotData.create(
        slot_id=slot_id,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@deprecated
@same_doc_as(PublicGetSlotData)
async def public_get_slot_data_async(
    slot_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Returns slot data (publicGetSlotData)

    ## The endpoint is going to be deprecated


    Get slot data.
    Other detail info:

      *  Returns : slot data

    Properties:
        url: /social/public/namespaces/{namespace}/users/{userId}/slots/{slotId}

        method: GET

        tags: ["Slot"]

        consumes: []

        produces: ["application/octet-stream"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        slot_id: (slotId) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - Any (Successful operation)

        404: Not Found - ErrorEntity (12141: Slot [{slotId}] not found in namespace [{namespace}])
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicGetSlotData.create(
        slot_id=slot_id,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@deprecated
@same_doc_as(PublicGetUserNamespaceSlots)
def public_get_user_namespace_slots(
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Returns slots for given user (publicGetUserNamespaceSlots)

    ## The endpoint is going to be deprecated


    Get list of slots for a given user in namespace.
    Other detail info:

      *  Returns : list of slots

    Properties:
        url: /social/public/namespaces/{namespace}/users/{userId}/slots

        method: GET

        tags: ["Slot"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - List[SlotInfo] (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicGetUserNamespaceSlots.create(
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@deprecated
@same_doc_as(PublicGetUserNamespaceSlots)
async def public_get_user_namespace_slots_async(
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Returns slots for given user (publicGetUserNamespaceSlots)

    ## The endpoint is going to be deprecated


    Get list of slots for a given user in namespace.
    Other detail info:

      *  Returns : list of slots

    Properties:
        url: /social/public/namespaces/{namespace}/users/{userId}/slots

        method: GET

        tags: ["Slot"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - List[SlotInfo] (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicGetUserNamespaceSlots.create(
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@deprecated
@same_doc_as(PublicUpdateUserNamespaceSlot)
def public_update_user_namespace_slot(
    slot_id: str,
    user_id: str,
    checksum: Optional[str] = None,
    custom_attribute: Optional[str] = None,
    file: Optional[Any] = None,
    label: Optional[str] = None,
    tags: Optional[List[str]] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Updates a slot (publicUpdateUserNamespaceSlot)

    ## The endpoint is going to be deprecated


    Updates a slot.
    Other detail info:

      *  Returns : updated slot

    Properties:
        url: /social/public/namespaces/{namespace}/users/{userId}/slots/{slotId}

        method: PUT

        tags: ["Slot"]

        consumes: ["multipart/form-data"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        checksum: (checksum) OPTIONAL str in form_data

        custom_attribute: (customAttribute) OPTIONAL str in form_data

        file: (file) OPTIONAL Any in form_data

        namespace: (namespace) REQUIRED str in path

        slot_id: (slotId) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        label: (label) OPTIONAL str in query

        tags: (tags) OPTIONAL List[str] in query

    Responses:
        200: OK - SlotInfo (successful operation)

        400: Bad Request - ErrorEntity (12121: Checksum mismatch for [{filename}] | 12122: [{filename}] exceeds the upload limit size of [{sizeLimit}] bytes)

        404: Not Found - ErrorEntity (12141: Slot [{slotId}] not found in namespace [{namespace}])
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicUpdateUserNamespaceSlot.create(
        slot_id=slot_id,
        user_id=user_id,
        checksum=checksum,
        custom_attribute=custom_attribute,
        file=file,
        label=label,
        tags=tags,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@deprecated
@same_doc_as(PublicUpdateUserNamespaceSlot)
async def public_update_user_namespace_slot_async(
    slot_id: str,
    user_id: str,
    checksum: Optional[str] = None,
    custom_attribute: Optional[str] = None,
    file: Optional[Any] = None,
    label: Optional[str] = None,
    tags: Optional[List[str]] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Updates a slot (publicUpdateUserNamespaceSlot)

    ## The endpoint is going to be deprecated


    Updates a slot.
    Other detail info:

      *  Returns : updated slot

    Properties:
        url: /social/public/namespaces/{namespace}/users/{userId}/slots/{slotId}

        method: PUT

        tags: ["Slot"]

        consumes: ["multipart/form-data"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        checksum: (checksum) OPTIONAL str in form_data

        custom_attribute: (customAttribute) OPTIONAL str in form_data

        file: (file) OPTIONAL Any in form_data

        namespace: (namespace) REQUIRED str in path

        slot_id: (slotId) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        label: (label) OPTIONAL str in query

        tags: (tags) OPTIONAL List[str] in query

    Responses:
        200: OK - SlotInfo (successful operation)

        400: Bad Request - ErrorEntity (12121: Checksum mismatch for [{filename}] | 12122: [{filename}] exceeds the upload limit size of [{sizeLimit}] bytes)

        404: Not Found - ErrorEntity (12141: Slot [{slotId}] not found in namespace [{namespace}])
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicUpdateUserNamespaceSlot.create(
        slot_id=slot_id,
        user_id=user_id,
        checksum=checksum,
        custom_attribute=custom_attribute,
        file=file,
        label=label,
        tags=tags,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@deprecated
@same_doc_as(PublicUpdateUserNamespaceSlotMetadata)
def public_update_user_namespace_slot_metadata(
    slot_id: str,
    user_id: str,
    body: Optional[SlotMetadataUpdate] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Updates the slot metadata (publicUpdateUserNamespaceSlotMetadata)

    ## The endpoint is going to be deprecated


    Updates the slot metadata.
    Other detail info:

      *  Returns : updated slot

    Properties:
        url: /social/public/namespaces/{namespace}/users/{userId}/slots/{slotId}/metadata

        method: PUT

        tags: ["Slot"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL SlotMetadataUpdate in body

        namespace: (namespace) REQUIRED str in path

        slot_id: (slotId) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - SlotInfo (successful operation)

        404: Not Found - ErrorEntity (12141: Slot [{slotId}] not found in namespace [{namespace}])
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicUpdateUserNamespaceSlotMetadata.create(
        slot_id=slot_id,
        user_id=user_id,
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@deprecated
@same_doc_as(PublicUpdateUserNamespaceSlotMetadata)
async def public_update_user_namespace_slot_metadata_async(
    slot_id: str,
    user_id: str,
    body: Optional[SlotMetadataUpdate] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Updates the slot metadata (publicUpdateUserNamespaceSlotMetadata)

    ## The endpoint is going to be deprecated


    Updates the slot metadata.
    Other detail info:

      *  Returns : updated slot

    Properties:
        url: /social/public/namespaces/{namespace}/users/{userId}/slots/{slotId}/metadata

        method: PUT

        tags: ["Slot"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL SlotMetadataUpdate in body

        namespace: (namespace) REQUIRED str in path

        slot_id: (slotId) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - SlotInfo (successful operation)

        404: Not Found - ErrorEntity (12141: Slot [{slotId}] not found in namespace [{namespace}])
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicUpdateUserNamespaceSlotMetadata.create(
        slot_id=slot_id,
        user_id=user_id,
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ErrorEntity
from ..models import ThirdPartySubscriptionOwnership
from ..models import ThirdPartySubscriptionTransactionHistoryPagingSlicedResult
from ..models import ThirdPartySubscriptionTransactionInfo
from ..models import ThirdPartySubscriptionTransactionPagingSlicedResult
from ..models import ThirdPartyUserSubscriptionInfo
from ..models import ThirdPartyUserSubscriptionPagingSlicedResult

from ..operations.iap_subscription import GetSubscriptionHistory
from ..operations.iap_subscription import (
    GetThirdPartyPlatformSubscriptionOwnershipByGroupId,
)
from ..operations.iap_subscription import (
    GetThirdPartyPlatformSubscriptionOwnershipByGroupIdPlatformEnum,
)
from ..operations.iap_subscription import (
    GetThirdPartyPlatformSubscriptionOwnershipByProductId,
)
from ..operations.iap_subscription import (
    GetThirdPartyPlatformSubscriptionOwnershipByProductIdPlatformEnum,
)
from ..operations.iap_subscription import GetThirdPartySubscriptionDetails
from ..operations.iap_subscription import GetThirdPartyUserSubscriptionDetails
from ..operations.iap_subscription import PublicQueryUserThirdPartySubscription
from ..operations.iap_subscription import (
    PublicQueryUserThirdPartySubscriptionPlatformEnum,
)
from ..operations.iap_subscription import QueryThirdPartySubscription
from ..operations.iap_subscription import QueryThirdPartySubscriptionPlatformEnum
from ..operations.iap_subscription import QueryUserThirdPartySubscription
from ..operations.iap_subscription import QueryUserThirdPartySubscriptionPlatformEnum
from ..operations.iap_subscription import QueryUserThirdPartySubscriptionTransactions
from ..operations.iap_subscription import (
    QueryUserThirdPartySubscriptionTransactionsPlatformEnum,
)
from ..operations.iap_subscription import SyncSubscription
from ..operations.iap_subscription import SyncSubscriptionTransaction
from ..models import (
    ThirdPartySubscriptionTransactionInfoPlatformEnum,
    ThirdPartySubscriptionTransactionInfoStatusEnum,
)
from ..models import (
    ThirdPartyUserSubscriptionInfoPlatformEnum,
    ThirdPartyUserSubscriptionInfoStatusEnum,
)


@same_doc_as(GetSubscriptionHistory)
def get_subscription_history(
    id_: str,
    user_id: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get User Subscription Transaction Update History (getSubscriptionHistory)

    Get Subscription Transaction Update History

    Properties:
        url: /platform/admin/namespaces/{namespace}/users/{userId}/iap/subscriptions/transactions/{id}/histories

        method: GET

        tags: ["IAP(Subscription)"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        id_: (id) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

    Responses:
        200: OK - ThirdPartySubscriptionTransactionHistoryPagingSlicedResult (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetSubscriptionHistory.create(
        id_=id_,
        user_id=user_id,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetSubscriptionHistory)
async def get_subscription_history_async(
    id_: str,
    user_id: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get User Subscription Transaction Update History (getSubscriptionHistory)

    Get Subscription Transaction Update History

    Properties:
        url: /platform/admin/namespaces/{namespace}/users/{userId}/iap/subscriptions/transactions/{id}/histories

        method: GET

        tags: ["IAP(Subscription)"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        id_: (id) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

    Responses:
        200: OK - ThirdPartySubscriptionTransactionHistoryPagingSlicedResult (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetSubscriptionHistory.create(
        id_=id_,
        user_id=user_id,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetThirdPartyPlatformSubscriptionOwnershipByGroupId)
def get_third_party_platform_subscription_ownership_by_group_id(
    group_id: str,
    platform: Union[
        str, GetThirdPartyPlatformSubscriptionOwnershipByGroupIdPlatformEnum
    ],
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get user third party platform subscription ownership by subscription group id (getThirdPartyPlatformSubscriptionOwnershipByGroupId)

    Get user third party subscription by subscription group id.

    Properties:
        url: /platform/admin/namespaces/{namespace}/users/{userId}/iap/subscriptions/platforms/{platform}/ownership/byGroupId

        method: GET

        tags: ["IAP(Subscription)"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        platform: (platform) REQUIRED Union[str, PlatformEnum] in path

        user_id: (userId) REQUIRED str in path

        group_id: (groupId) REQUIRED str in query

    Responses:
        200: OK - ThirdPartySubscriptionOwnership (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetThirdPartyPlatformSubscriptionOwnershipByGroupId.create(
        group_id=group_id,
        platform=platform,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetThirdPartyPlatformSubscriptionOwnershipByGroupId)
async def get_third_party_platform_subscription_ownership_by_group_id_async(
    group_id: str,
    platform: Union[
        str, GetThirdPartyPlatformSubscriptionOwnershipByGroupIdPlatformEnum
    ],
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get user third party platform subscription ownership by subscription group id (getThirdPartyPlatformSubscriptionOwnershipByGroupId)

    Get user third party subscription by subscription group id.

    Properties:
        url: /platform/admin/namespaces/{namespace}/users/{userId}/iap/subscriptions/platforms/{platform}/ownership/byGroupId

        method: GET

        tags: ["IAP(Subscription)"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        platform: (platform) REQUIRED Union[str, PlatformEnum] in path

        user_id: (userId) REQUIRED str in path

        group_id: (groupId) REQUIRED str in query

    Responses:
        200: OK - ThirdPartySubscriptionOwnership (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetThirdPartyPlatformSubscriptionOwnershipByGroupId.create(
        group_id=group_id,
        platform=platform,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetThirdPartyPlatformSubscriptionOwnershipByProductId)
def get_third_party_platform_subscription_ownership_by_product_id(
    platform: Union[
        str, GetThirdPartyPlatformSubscriptionOwnershipByProductIdPlatformEnum
    ],
    product_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get user third party platform subscription ownership by subscription product id (getThirdPartyPlatformSubscriptionOwnershipByProductId)

    Get user third party subscription by subscription product id.

    Properties:
        url: /platform/admin/namespaces/{namespace}/users/{userId}/iap/subscriptions/platforms/{platform}/ownership/byProductId

        method: GET

        tags: ["IAP(Subscription)"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        platform: (platform) REQUIRED Union[str, PlatformEnum] in path

        user_id: (userId) REQUIRED str in path

        product_id: (productId) REQUIRED str in query

    Responses:
        200: OK - ThirdPartySubscriptionOwnership (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetThirdPartyPlatformSubscriptionOwnershipByProductId.create(
        platform=platform,
        product_id=product_id,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetThirdPartyPlatformSubscriptionOwnershipByProductId)
async def get_third_party_platform_subscription_ownership_by_product_id_async(
    platform: Union[
        str, GetThirdPartyPlatformSubscriptionOwnershipByProductIdPlatformEnum
    ],
    product_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get user third party platform subscription ownership by subscription product id (getThirdPartyPlatformSubscriptionOwnershipByProductId)

    Get user third party subscription by subscription product id.

    Properties:
        url: /platform/admin/namespaces/{namespace}/users/{userId}/iap/subscriptions/platforms/{platform}/ownership/byProductId

        method: GET

        tags: ["IAP(Subscription)"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        platform: (platform) REQUIRED Union[str, PlatformEnum] in path

        user_id: (userId) REQUIRED str in path

        product_id: (productId) REQUIRED str in query

    Responses:
        200: OK - ThirdPartySubscriptionOwnership (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetThirdPartyPlatformSubscriptionOwnershipByProductId.create(
        platform=platform,
        product_id=product_id,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetThirdPartySubscriptionDetails)
def get_third_party_subscription_details(
    id_: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Admin get user subscription transaction details. (getThirdPartySubscriptionDetails)

    Admin get user subscription details.Other detail info:

      * Returns :

    Properties:
        url: /platform/admin/namespaces/{namespace}/users/{userId}/iap/subscriptions/transactions/{id}

        method: GET

        tags: ["IAP(Subscription)"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        id_: (id) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ThirdPartySubscriptionTransactionInfo (successful operation)

        404: Not Found - ErrorEntity (39149: Third Party Subscription [{id}] not found for user [{userId}] in the namespace [{namespace}].)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetThirdPartySubscriptionDetails.create(
        id_=id_,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetThirdPartySubscriptionDetails)
async def get_third_party_subscription_details_async(
    id_: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Admin get user subscription transaction details. (getThirdPartySubscriptionDetails)

    Admin get user subscription details.Other detail info:

      * Returns :

    Properties:
        url: /platform/admin/namespaces/{namespace}/users/{userId}/iap/subscriptions/transactions/{id}

        method: GET

        tags: ["IAP(Subscription)"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        id_: (id) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ThirdPartySubscriptionTransactionInfo (successful operation)

        404: Not Found - ErrorEntity (39149: Third Party Subscription [{id}] not found for user [{userId}] in the namespace [{namespace}].)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetThirdPartySubscriptionDetails.create(
        id_=id_,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetThirdPartyUserSubscriptionDetails)
def get_third_party_user_subscription_details(
    id_: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Admin get user subscription details. (getThirdPartyUserSubscriptionDetails)

    Admin get user subscription details.Other detail info:

      * Returns :

    Properties:
        url: /platform/admin/namespaces/{namespace}/users/{userId}/iap/subscriptions/{id}

        method: GET

        tags: ["IAP(Subscription)"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        id_: (id) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ThirdPartyUserSubscriptionInfo (successful operation)

        404: Not Found - ErrorEntity (39149: Third Party User Subscription [{id}] not found for user [{userId}] in the namespace [{namespace}].)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetThirdPartyUserSubscriptionDetails.create(
        id_=id_,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetThirdPartyUserSubscriptionDetails)
async def get_third_party_user_subscription_details_async(
    id_: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Admin get user subscription details. (getThirdPartyUserSubscriptionDetails)

    Admin get user subscription details.Other detail info:

      * Returns :

    Properties:
        url: /platform/admin/namespaces/{namespace}/users/{userId}/iap/subscriptions/{id}

        method: GET

        tags: ["IAP(Subscription)"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        id_: (id) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ThirdPartyUserSubscriptionInfo (successful operation)

        404: Not Found - ErrorEntity (39149: Third Party User Subscription [{id}] not found for user [{userId}] in the namespace [{namespace}].)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetThirdPartyUserSubscriptionDetails.create(
        id_=id_,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicQueryUserThirdPartySubscription)
def public_query_user_third_party_subscription(
    platform: Union[str, PublicQueryUserThirdPartySubscriptionPlatformEnum],
    user_id: str,
    active_only: Optional[bool] = None,
    group_id: Optional[str] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    product_id: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query user subscription. (publicQueryUserThirdPartySubscription)

    Query user subscription, default sort by updatedAtOther detail info:

      * Returns :

    Properties:
        url: /platform/public/namespaces/{namespace}/users/{userId}/iap/subscriptions/platforms/{platform}

        method: GET

        tags: ["IAP(Subscription)"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        platform: (platform) REQUIRED Union[str, PlatformEnum] in path

        user_id: (userId) REQUIRED str in path

        active_only: (activeOnly) OPTIONAL bool in query

        group_id: (groupId) OPTIONAL str in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        product_id: (productId) OPTIONAL str in query

    Responses:
        200: OK - ThirdPartyUserSubscriptionPagingSlicedResult (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicQueryUserThirdPartySubscription.create(
        platform=platform,
        user_id=user_id,
        active_only=active_only,
        group_id=group_id,
        limit=limit,
        offset=offset,
        product_id=product_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicQueryUserThirdPartySubscription)
async def public_query_user_third_party_subscription_async(
    platform: Union[str, PublicQueryUserThirdPartySubscriptionPlatformEnum],
    user_id: str,
    active_only: Optional[bool] = None,
    group_id: Optional[str] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    product_id: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query user subscription. (publicQueryUserThirdPartySubscription)

    Query user subscription, default sort by updatedAtOther detail info:

      * Returns :

    Properties:
        url: /platform/public/namespaces/{namespace}/users/{userId}/iap/subscriptions/platforms/{platform}

        method: GET

        tags: ["IAP(Subscription)"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        platform: (platform) REQUIRED Union[str, PlatformEnum] in path

        user_id: (userId) REQUIRED str in path

        active_only: (activeOnly) OPTIONAL bool in query

        group_id: (groupId) OPTIONAL str in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        product_id: (productId) OPTIONAL str in query

    Responses:
        200: OK - ThirdPartyUserSubscriptionPagingSlicedResult (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicQueryUserThirdPartySubscription.create(
        platform=platform,
        user_id=user_id,
        active_only=active_only,
        group_id=group_id,
        limit=limit,
        offset=offset,
        product_id=product_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(QueryThirdPartySubscription)
def query_third_party_subscription(
    active_only: Optional[bool] = None,
    group_id: Optional[str] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    platform: Optional[Union[str, QueryThirdPartySubscriptionPlatformEnum]] = None,
    product_id: Optional[str] = None,
    user_id: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query subscriptions. (queryThirdPartySubscription)

    Query subscriptions, default sort by updatedAt Other detail info:

      * Returns :

    Properties:
        url: /platform/admin/namespaces/{namespace}/iap/subscriptions

        method: GET

        tags: ["IAP(Subscription)"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        active_only: (activeOnly) OPTIONAL bool in query

        group_id: (groupId) OPTIONAL str in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        platform: (platform) OPTIONAL Union[str, PlatformEnum] in query

        product_id: (productId) OPTIONAL str in query

        user_id: (userId) OPTIONAL str in query

    Responses:
        200: OK - ThirdPartyUserSubscriptionPagingSlicedResult (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryThirdPartySubscription.create(
        active_only=active_only,
        group_id=group_id,
        limit=limit,
        offset=offset,
        platform=platform,
        product_id=product_id,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(QueryThirdPartySubscription)
async def query_third_party_subscription_async(
    active_only: Optional[bool] = None,
    group_id: Optional[str] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    platform: Optional[Union[str, QueryThirdPartySubscriptionPlatformEnum]] = None,
    product_id: Optional[str] = None,
    user_id: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query subscriptions. (queryThirdPartySubscription)

    Query subscriptions, default sort by updatedAt Other detail info:

      * Returns :

    Properties:
        url: /platform/admin/namespaces/{namespace}/iap/subscriptions

        method: GET

        tags: ["IAP(Subscription)"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        active_only: (activeOnly) OPTIONAL bool in query

        group_id: (groupId) OPTIONAL str in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        platform: (platform) OPTIONAL Union[str, PlatformEnum] in query

        product_id: (productId) OPTIONAL str in query

        user_id: (userId) OPTIONAL str in query

    Responses:
        200: OK - ThirdPartyUserSubscriptionPagingSlicedResult (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryThirdPartySubscription.create(
        active_only=active_only,
        group_id=group_id,
        limit=limit,
        offset=offset,
        platform=platform,
        product_id=product_id,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(QueryUserThirdPartySubscription)
def query_user_third_party_subscription(
    user_id: str,
    active_only: Optional[bool] = None,
    group_id: Optional[str] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    platform: Optional[Union[str, QueryUserThirdPartySubscriptionPlatformEnum]] = None,
    product_id: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query user subscription. (queryUserThirdPartySubscription)

    Query user subscription, default sort by updatedAtOther detail info:

      * Returns :

    Properties:
        url: /platform/admin/namespaces/{namespace}/users/{userId}/iap/subscriptions

        method: GET

        tags: ["IAP(Subscription)"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        active_only: (activeOnly) OPTIONAL bool in query

        group_id: (groupId) OPTIONAL str in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        platform: (platform) OPTIONAL Union[str, PlatformEnum] in query

        product_id: (productId) OPTIONAL str in query

    Responses:
        200: OK - ThirdPartyUserSubscriptionPagingSlicedResult (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryUserThirdPartySubscription.create(
        user_id=user_id,
        active_only=active_only,
        group_id=group_id,
        limit=limit,
        offset=offset,
        platform=platform,
        product_id=product_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(QueryUserThirdPartySubscription)
async def query_user_third_party_subscription_async(
    user_id: str,
    active_only: Optional[bool] = None,
    group_id: Optional[str] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    platform: Optional[Union[str, QueryUserThirdPartySubscriptionPlatformEnum]] = None,
    product_id: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query user subscription. (queryUserThirdPartySubscription)

    Query user subscription, default sort by updatedAtOther detail info:

      * Returns :

    Properties:
        url: /platform/admin/namespaces/{namespace}/users/{userId}/iap/subscriptions

        method: GET

        tags: ["IAP(Subscription)"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        active_only: (activeOnly) OPTIONAL bool in query

        group_id: (groupId) OPTIONAL str in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        platform: (platform) OPTIONAL Union[str, PlatformEnum] in query

        product_id: (productId) OPTIONAL str in query

    Responses:
        200: OK - ThirdPartyUserSubscriptionPagingSlicedResult (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryUserThirdPartySubscription.create(
        user_id=user_id,
        active_only=active_only,
        group_id=group_id,
        limit=limit,
        offset=offset,
        platform=platform,
        product_id=product_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(QueryUserThirdPartySubscriptionTransactions)
def query_user_third_party_subscription_transactions(
    user_id: str,
    active_only: Optional[bool] = None,
    group_id: Optional[str] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    platform: Optional[
        Union[str, QueryUserThirdPartySubscriptionTransactionsPlatformEnum]
    ] = None,
    product_id: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Admin query user subscription transactions. (queryUserThirdPartySubscriptionTransactions)

    Admin query user subscription transactions, default sort by startAt timeOther detail info:

      * Returns :

    Properties:
        url: /platform/admin/namespaces/{namespace}/users/{userId}/iap/subscriptions/transactions

        method: GET

        tags: ["IAP(Subscription)"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        active_only: (activeOnly) OPTIONAL bool in query

        group_id: (groupId) OPTIONAL str in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        platform: (platform) OPTIONAL Union[str, PlatformEnum] in query

        product_id: (productId) OPTIONAL str in query

    Responses:
        200: OK - ThirdPartySubscriptionTransactionPagingSlicedResult (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryUserThirdPartySubscriptionTransactions.create(
        user_id=user_id,
        active_only=active_only,
        group_id=group_id,
        limit=limit,
        offset=offset,
        platform=platform,
        product_id=product_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(QueryUserThirdPartySubscriptionTransactions)
async def query_user_third_party_subscription_transactions_async(
    user_id: str,
    active_only: Optional[bool] = None,
    group_id: Optional[str] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    platform: Optional[
        Union[str, QueryUserThirdPartySubscriptionTransactionsPlatformEnum]
    ] = None,
    product_id: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Admin query user subscription transactions. (queryUserThirdPartySubscriptionTransactions)

    Admin query user subscription transactions, default sort by startAt timeOther detail info:

      * Returns :

    Properties:
        url: /platform/admin/namespaces/{namespace}/users/{userId}/iap/subscriptions/transactions

        method: GET

        tags: ["IAP(Subscription)"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        active_only: (activeOnly) OPTIONAL bool in query

        group_id: (groupId) OPTIONAL str in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        platform: (platform) OPTIONAL Union[str, PlatformEnum] in query

        product_id: (productId) OPTIONAL str in query

    Responses:
        200: OK - ThirdPartySubscriptionTransactionPagingSlicedResult (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryUserThirdPartySubscriptionTransactions.create(
        user_id=user_id,
        active_only=active_only,
        group_id=group_id,
        limit=limit,
        offset=offset,
        platform=platform,
        product_id=product_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(SyncSubscription)
def sync_subscription(
    id_: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Sync Subscription Status (syncSubscription)

    Sync Subscription Status

    Properties:
        url: /platform/admin/namespaces/{namespace}/users/{userId}/iap/subscriptions/{id}/sync

        method: PUT

        tags: ["IAP(Subscription)"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        id_: (id) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ThirdPartyUserSubscriptionInfo (successful operation)

        400: Bad Request - ErrorEntity (39131: Invalid Apple IAP config under namespace [{namespace}]: [{message}] | 39136: Request Apple API failed with status code [{statusCode}] and error message [{message}] | 39137: Verify Apple transaction failed with status [{status}] and error message [{message}])

        404: Not Found - ErrorEntity (39149: Third Party Subscription Transaction [{id}] not found for user [{userId}] in the namespace [{namespace}]. | 39150: Third Party User Subscription [{id}] not found for user [{userId}] in the namespace [{namespace}]..)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = SyncSubscription.create(
        id_=id_,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(SyncSubscription)
async def sync_subscription_async(
    id_: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Sync Subscription Status (syncSubscription)

    Sync Subscription Status

    Properties:
        url: /platform/admin/namespaces/{namespace}/users/{userId}/iap/subscriptions/{id}/sync

        method: PUT

        tags: ["IAP(Subscription)"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        id_: (id) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ThirdPartyUserSubscriptionInfo (successful operation)

        400: Bad Request - ErrorEntity (39131: Invalid Apple IAP config under namespace [{namespace}]: [{message}] | 39136: Request Apple API failed with status code [{statusCode}] and error message [{message}] | 39137: Verify Apple transaction failed with status [{status}] and error message [{message}])

        404: Not Found - ErrorEntity (39149: Third Party Subscription Transaction [{id}] not found for user [{userId}] in the namespace [{namespace}]. | 39150: Third Party User Subscription [{id}] not found for user [{userId}] in the namespace [{namespace}]..)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = SyncSubscription.create(
        id_=id_,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(SyncSubscriptionTransaction)
def sync_subscription_transaction(
    id_: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Sync Subscription transaction (syncSubscriptionTransaction)

    Sync Subscription Status

    Properties:
        url: /platform/admin/namespaces/{namespace}/users/{userId}/iap/subscriptions/transactions/{id}/sync

        method: PUT

        tags: ["IAP(Subscription)"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        id_: (id) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ThirdPartySubscriptionTransactionInfo (successful operation)

        400: Bad Request - ErrorEntity (39131: Invalid Apple IAP config under namespace [{namespace}]: [{message}] | 39136: Request Apple API failed with status code [{statusCode}] and error message [{message}] | 39137: Verify Apple transaction failed with status [{status}] and error message [{message}])

        404: Not Found - ErrorEntity (39149: Third Party Subscription Transaction [{id}] not found for user [{userId}] in the namespace [{namespace}].)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = SyncSubscriptionTransaction.create(
        id_=id_,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(SyncSubscriptionTransaction)
async def sync_subscription_transaction_async(
    id_: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Sync Subscription transaction (syncSubscriptionTransaction)

    Sync Subscription Status

    Properties:
        url: /platform/admin/namespaces/{namespace}/users/{userId}/iap/subscriptions/transactions/{id}/sync

        method: PUT

        tags: ["IAP(Subscription)"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        id_: (id) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ThirdPartySubscriptionTransactionInfo (successful operation)

        400: Bad Request - ErrorEntity (39131: Invalid Apple IAP config under namespace [{namespace}]: [{message}] | 39136: Request Apple API failed with status code [{statusCode}] and error message [{message}] | 39137: Verify Apple transaction failed with status [{status}] and error message [{message}])

        404: Not Found - ErrorEntity (39149: Third Party Subscription Transaction [{id}] not found for user [{userId}] in the namespace [{namespace}].)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = SyncSubscriptionTransaction.create(
        id_=id_,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Session Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model


class ApimodelsPSNAppServerCredentialRecord(Model):
    """Apimodels PSN app server credential record (apimodels.PSNAppServerCredentialRecord)

    Properties:
        client_id: (clientId) REQUIRED str

        client_secret: (clientSecret) REQUIRED str

        scope: (scope) REQUIRED str
    """

    # region fields

    client_id: str  # REQUIRED
    client_secret: str  # REQUIRED
    scope: str  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_client_id(self, value: str) -> ApimodelsPSNAppServerCredentialRecord:
        self.client_id = value
        return self

    def with_client_secret(self, value: str) -> ApimodelsPSNAppServerCredentialRecord:
        self.client_secret = value
        return self

    def with_scope(self, value: str) -> ApimodelsPSNAppServerCredentialRecord:
        self.scope = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "client_id"):
            result["clientId"] = str(self.client_id)
        elif include_empty:
            result["clientId"] = ""
        if hasattr(self, "client_secret"):
            result["clientSecret"] = str(self.client_secret)
        elif include_empty:
            result["clientSecret"] = ""
        if hasattr(self, "scope"):
            result["scope"] = str(self.scope)
        elif include_empty:
            result["scope"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls, client_id: str, client_secret: str, scope: str, **kwargs
    ) -> ApimodelsPSNAppServerCredentialRecord:
        instance = cls()
        instance.client_id = client_id
        instance.client_secret = client_secret
        instance.scope = scope
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ApimodelsPSNAppServerCredentialRecord:
        instance = cls()
        if not dict_:
            return instance
        if "clientId" in dict_ and dict_["clientId"] is not None:
            instance.client_id = str(dict_["clientId"])
        elif include_empty:
            instance.client_id = ""
        if "clientSecret" in dict_ and dict_["clientSecret"] is not None:
            instance.client_secret = str(dict_["clientSecret"])
        elif include_empty:
            instance.client_secret = ""
        if "scope" in dict_ and dict_["scope"] is not None:
            instance.scope = str(dict_["scope"])
        elif include_empty:
            instance.scope = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ApimodelsPSNAppServerCredentialRecord]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ApimodelsPSNAppServerCredentialRecord]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ApimodelsPSNAppServerCredentialRecord,
        List[ApimodelsPSNAppServerCredentialRecord],
        Dict[Any, ApimodelsPSNAppServerCredentialRecord],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "clientId": "client_id",
            "clientSecret": "client_secret",
            "scope": "scope",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "clientId": True,
            "clientSecret": True,
            "scope": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ModelConfigValueResponseV3
from ..models import RestErrorResponse

from ..operations.config import AdminGetConfigValueV3
from ..operations.config import PublicGetConfigValueV3


@same_doc_as(AdminGetConfigValueV3)
def admin_get_config_value_v3(
    config_key: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get Config Value (AdminGetConfigValueV3)

    This endpoint return the value of config key. The namespace should be publisher namespace or studio namespace.

    **Supported config key:**
    * uniqueDisplayNameEnabled
    * usernameDisabled
    * mandatoryEmailVerificationEnabled

    Properties:
        url: /iam/v3/admin/namespaces/{namespace}/config/{configKey}

        method: GET

        tags: ["Config"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        config_key: (configKey) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelConfigValueResponseV3 (OK)

        400: Bad Request - RestErrorResponse (20002: validation error)

        500: Internal Server Error - RestErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetConfigValueV3.create(
        config_key=config_key,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetConfigValueV3)
async def admin_get_config_value_v3_async(
    config_key: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get Config Value (AdminGetConfigValueV3)

    This endpoint return the value of config key. The namespace should be publisher namespace or studio namespace.

    **Supported config key:**
    * uniqueDisplayNameEnabled
    * usernameDisabled
    * mandatoryEmailVerificationEnabled

    Properties:
        url: /iam/v3/admin/namespaces/{namespace}/config/{configKey}

        method: GET

        tags: ["Config"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        config_key: (configKey) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelConfigValueResponseV3 (OK)

        400: Bad Request - RestErrorResponse (20002: validation error)

        500: Internal Server Error - RestErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetConfigValueV3.create(
        config_key=config_key,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicGetConfigValueV3)
def public_get_config_value_v3(
    config_key: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get Config Value (PublicGetConfigValueV3)

    This endpoint return the value of config key. The namespace should be publisher namespace or studio namespace.
    Note: this endpoint does not need any authorization.

    **Supported config key:**
    * uniqueDisplayNameEnabled
    * usernameDisabled
    * mandatoryEmailVerificationEnabled
    * verificationCodeType

    If the key is verificationCodeType, then possible value format will be '{collection}:{N}'; example: 'ABCDEFGHI:6', 'ABCDEFGHI1234:8','01234567894:7'

    Properties:
        url: /iam/v3/public/namespaces/{namespace}/config/{configKey}

        method: GET

        tags: ["Config"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        config_key: (configKey) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelConfigValueResponseV3 (OK)

        400: Bad Request - RestErrorResponse (20002: validation error)

        500: Internal Server Error - RestErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicGetConfigValueV3.create(
        config_key=config_key,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicGetConfigValueV3)
async def public_get_config_value_v3_async(
    config_key: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get Config Value (PublicGetConfigValueV3)

    This endpoint return the value of config key. The namespace should be publisher namespace or studio namespace.
    Note: this endpoint does not need any authorization.

    **Supported config key:**
    * uniqueDisplayNameEnabled
    * usernameDisabled
    * mandatoryEmailVerificationEnabled
    * verificationCodeType

    If the key is verificationCodeType, then possible value format will be '{collection}:{N}'; example: 'ABCDEFGHI:6', 'ABCDEFGHI1234:8','01234567894:7'

    Properties:
        url: /iam/v3/public/namespaces/{namespace}/config/{configKey}

        method: GET

        tags: ["Config"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        config_key: (configKey) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelConfigValueResponseV3 (OK)

        400: Bad Request - RestErrorResponse (20002: validation error)

        500: Internal Server Error - RestErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicGetConfigValueV3.create(
        config_key=config_key,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ModelRoleOverrideResponse
from ..models import ModelRoleOverrideSourceResponse
from ..models import ModelRoleOverrideStatsUpdateRequest
from ..models import ModelRoleOverrideUpdateRequest
from ..models import ModelRolePermissionResponseV3
from ..models import RestErrorResponse

from ..operations.override_role_config_v3 import AdminChangeRoleOverrideConfigStatusV3
from ..operations.override_role_config_v3 import (
    AdminChangeRoleOverrideConfigStatusV3IdentityEnum,
)
from ..operations.override_role_config_v3 import AdminGetRoleNamespacePermissionV3
from ..operations.override_role_config_v3 import AdminGetRoleOverrideConfigV3
from ..operations.override_role_config_v3 import (
    AdminGetRoleOverrideConfigV3IdentityEnum,
)
from ..operations.override_role_config_v3 import AdminGetRoleSourceV3
from ..operations.override_role_config_v3 import AdminGetRoleSourceV3IdentityEnum
from ..operations.override_role_config_v3 import AdminUpdateRoleOverrideConfigV3
from ..operations.override_role_config_v3 import (
    AdminUpdateRoleOverrideConfigV3IdentityEnum,
)


@same_doc_as(AdminChangeRoleOverrideConfigStatusV3)
def admin_change_role_override_config_status_v3(
    body: ModelRoleOverrideStatsUpdateRequest,
    identity: Union[str, AdminChangeRoleOverrideConfigStatusV3IdentityEnum],
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Change role override config active status (AdminChangeRoleOverrideConfigStatusV3)

    Enable or disable the target role override feature in path namespace.
    Note:
    This API has upsert behavior, if there is no config yet, it will create a new one first.

    Properties:
        url: /iam/v3/admin/namespaces/{namespace}/roleoverride/status

        method: PATCH

        tags: ["Override Role Config v3"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelRoleOverrideStatsUpdateRequest in body

        namespace: (namespace) REQUIRED str in path

        identity: (identity) REQUIRED Union[str, IdentityEnum] in query

    Responses:
        200: OK - ModelRoleOverrideResponse (OK)

        401: Unauthorized - RestErrorResponse (20001: unauthorized access)

        403: Forbidden - RestErrorResponse (20013: insufficient permissions)

        500: Internal Server Error - RestErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminChangeRoleOverrideConfigStatusV3.create(
        body=body,
        identity=identity,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminChangeRoleOverrideConfigStatusV3)
async def admin_change_role_override_config_status_v3_async(
    body: ModelRoleOverrideStatsUpdateRequest,
    identity: Union[str, AdminChangeRoleOverrideConfigStatusV3IdentityEnum],
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Change role override config active status (AdminChangeRoleOverrideConfigStatusV3)

    Enable or disable the target role override feature in path namespace.
    Note:
    This API has upsert behavior, if there is no config yet, it will create a new one first.

    Properties:
        url: /iam/v3/admin/namespaces/{namespace}/roleoverride/status

        method: PATCH

        tags: ["Override Role Config v3"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelRoleOverrideStatsUpdateRequest in body

        namespace: (namespace) REQUIRED str in path

        identity: (identity) REQUIRED Union[str, IdentityEnum] in query

    Responses:
        200: OK - ModelRoleOverrideResponse (OK)

        401: Unauthorized - RestErrorResponse (20001: unauthorized access)

        403: Forbidden - RestErrorResponse (20013: insufficient permissions)

        500: Internal Server Error - RestErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminChangeRoleOverrideConfigStatusV3.create(
        body=body,
        identity=identity,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminGetRoleNamespacePermissionV3)
def admin_get_role_namespace_permission_v3(
    role_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get role namespace permission (AdminGetRoleNamespacePermissionV3)

    Get role namespace permission set.

    Properties:
        url: /iam/v3/admin/namespaces/{namespace}/roleoverride/{roleId}/permissions

        method: GET

        tags: ["Override Role Config v3"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        role_id: (roleId) REQUIRED str in path

    Responses:
        200: OK - ModelRolePermissionResponseV3 (OK)

        401: Unauthorized - RestErrorResponse (20001: unauthorized access)

        403: Forbidden - RestErrorResponse (20013: insufficient permissions)

        404: Not Found - RestErrorResponse (10456: role not found)

        500: Internal Server Error - RestErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetRoleNamespacePermissionV3.create(
        role_id=role_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetRoleNamespacePermissionV3)
async def admin_get_role_namespace_permission_v3_async(
    role_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get role namespace permission (AdminGetRoleNamespacePermissionV3)

    Get role namespace permission set.

    Properties:
        url: /iam/v3/admin/namespaces/{namespace}/roleoverride/{roleId}/permissions

        method: GET

        tags: ["Override Role Config v3"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        role_id: (roleId) REQUIRED str in path

    Responses:
        200: OK - ModelRolePermissionResponseV3 (OK)

        401: Unauthorized - RestErrorResponse (20001: unauthorized access)

        403: Forbidden - RestErrorResponse (20013: insufficient permissions)

        404: Not Found - RestErrorResponse (10456: role not found)

        500: Internal Server Error - RestErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetRoleNamespacePermissionV3.create(
        role_id=role_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminGetRoleOverrideConfigV3)
def admin_get_role_override_config_v3(
    identity: Union[str, AdminGetRoleOverrideConfigV3IdentityEnum],
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get role override config (AdminGetRoleOverrideConfigV3)

    Get role override config.
    This API has upsert behavior, if there is no config yet, it will create a new one with inactive status.

    Properties:
        url: /iam/v3/admin/namespaces/{namespace}/roleoverride

        method: GET

        tags: ["Override Role Config v3"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        identity: (identity) REQUIRED Union[str, IdentityEnum] in query

    Responses:
        200: OK - ModelRoleOverrideResponse (OK)

        400: Bad Request - RestErrorResponse (20002: validation error | 20019: unable to parse request body)

        401: Unauthorized - RestErrorResponse (20001: unauthorized access)

        403: Forbidden - RestErrorResponse (20013: insufficient permissions)

        500: Internal Server Error - RestErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetRoleOverrideConfigV3.create(
        identity=identity,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetRoleOverrideConfigV3)
async def admin_get_role_override_config_v3_async(
    identity: Union[str, AdminGetRoleOverrideConfigV3IdentityEnum],
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get role override config (AdminGetRoleOverrideConfigV3)

    Get role override config.
    This API has upsert behavior, if there is no config yet, it will create a new one with inactive status.

    Properties:
        url: /iam/v3/admin/namespaces/{namespace}/roleoverride

        method: GET

        tags: ["Override Role Config v3"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        identity: (identity) REQUIRED Union[str, IdentityEnum] in query

    Responses:
        200: OK - ModelRoleOverrideResponse (OK)

        400: Bad Request - RestErrorResponse (20002: validation error | 20019: unable to parse request body)

        401: Unauthorized - RestErrorResponse (20001: unauthorized access)

        403: Forbidden - RestErrorResponse (20013: insufficient permissions)

        500: Internal Server Error - RestErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetRoleOverrideConfigV3.create(
        identity=identity,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminGetRoleSourceV3)
def admin_get_role_source_v3(
    identity: Union[str, AdminGetRoleSourceV3IdentityEnum],
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get role source permission set (AdminGetRoleSourceV3)

    Get role source permission set.

    Properties:
        url: /iam/v3/admin/namespaces/{namespace}/roleoverride/source

        method: GET

        tags: ["Override Role Config v3"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        identity: (identity) REQUIRED Union[str, IdentityEnum] in query

    Responses:
        200: OK - ModelRoleOverrideSourceResponse (OK)

        400: Bad Request - RestErrorResponse (20002: validation error)

        401: Unauthorized - RestErrorResponse (20001: unauthorized access)

        403: Forbidden - RestErrorResponse (20013: insufficient permissions)

        404: Not Found - RestErrorResponse (10456: role not found)

        500: Internal Server Error - RestErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetRoleSourceV3.create(
        identity=identity,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetRoleSourceV3)
async def admin_get_role_source_v3_async(
    identity: Union[str, AdminGetRoleSourceV3IdentityEnum],
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get role source permission set (AdminGetRoleSourceV3)

    Get role source permission set.

    Properties:
        url: /iam/v3/admin/namespaces/{namespace}/roleoverride/source

        method: GET

        tags: ["Override Role Config v3"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        identity: (identity) REQUIRED Union[str, IdentityEnum] in query

    Responses:
        200: OK - ModelRoleOverrideSourceResponse (OK)

        400: Bad Request - RestErrorResponse (20002: validation error)

        401: Unauthorized - RestErrorResponse (20001: unauthorized access)

        403: Forbidden - RestErrorResponse (20013: insufficient permissions)

        404: Not Found - RestErrorResponse (10456: role not found)

        500: Internal Server Error - RestErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetRoleSourceV3.create(
        identity=identity,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminUpdateRoleOverrideConfigV3)
def admin_update_role_override_config_v3(
    body: ModelRoleOverrideUpdateRequest,
    identity: Union[str, AdminUpdateRoleOverrideConfigV3IdentityEnum],
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update role override config (AdminUpdateRoleOverrideConfigV3)

    This API is for updating role override config.
    Note:
    This API has upsert behavior, if there is no config yet, it will create a new one first.

    Properties:
        url: /iam/v3/admin/namespaces/{namespace}/roleoverride

        method: PATCH

        tags: ["Override Role Config v3"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelRoleOverrideUpdateRequest in body

        namespace: (namespace) REQUIRED str in path

        identity: (identity) REQUIRED Union[str, IdentityEnum] in query

    Responses:
        200: OK - ModelRoleOverrideResponse (OK)

        400: Bad Request - RestErrorResponse (20002: validation error | 20019: unable to parse request body)

        401: Unauthorized - RestErrorResponse (20001: unauthorized access)

        403: Forbidden - RestErrorResponse (20013: insufficient permissions)

        500: Internal Server Error - RestErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminUpdateRoleOverrideConfigV3.create(
        body=body,
        identity=identity,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminUpdateRoleOverrideConfigV3)
async def admin_update_role_override_config_v3_async(
    body: ModelRoleOverrideUpdateRequest,
    identity: Union[str, AdminUpdateRoleOverrideConfigV3IdentityEnum],
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update role override config (AdminUpdateRoleOverrideConfigV3)

    This API is for updating role override config.
    Note:
    This API has upsert behavior, if there is no config yet, it will create a new one first.

    Properties:
        url: /iam/v3/admin/namespaces/{namespace}/roleoverride

        method: PATCH

        tags: ["Override Role Config v3"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelRoleOverrideUpdateRequest in body

        namespace: (namespace) REQUIRED str in path

        identity: (identity) REQUIRED Union[str, IdentityEnum] in query

    Responses:
        200: OK - ModelRoleOverrideResponse (OK)

        400: Bad Request - RestErrorResponse (20002: validation error | 20019: unable to parse request body)

        401: Unauthorized - RestErrorResponse (20001: unauthorized access)

        403: Forbidden - RestErrorResponse (20013: insufficient permissions)

        500: Internal Server Error - RestErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminUpdateRoleOverrideConfigV3.create(
        body=body,
        identity=identity,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

# AccelByte Gaming Services Iam Service

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from .....core import Operation
from .....core import HeaderStr
from .....core import HttpResponse
from .....core import StrEnum

from ...models import OauthmodelTargetTokenCodeResponse


class CodeChallengeMethodEnum(StrEnum):
    S256 = "S256"
    PLAIN = "plain"


class RequestTokenExchangeCodeV3(Operation):
    """Request code to get a new token (RequestTokenExchangeCodeV3)

    This endpoint is being used to request the code to exchange a new token.
    The target new token's clientId should NOT be same with current using one.
    Path namespace should be target namespace.
    Client ID should match the target namespace.

    The code in response can be consumed by `/iam/v3/token/exchange`

    Properties:
        url: /iam/v3/namespace/{namespace}/token/request

        method: POST

        tags: ["OAuth2.0 - Extension"]

        consumes: ["application/x-www-form-urlencoded"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        client_id: (client_id) REQUIRED str in form_data

        namespace: (namespace) REQUIRED str in path

        code_challenge: (code_challenge) OPTIONAL str in query

        code_challenge_method: (code_challenge_method) OPTIONAL Union[str, CodeChallengeMethodEnum] in query

    Responses:
        200: OK - OauthmodelTargetTokenCodeResponse (Succeed to request token exchange code.)
    """

    # region fields

    _url: str = "/iam/v3/namespace/{namespace}/token/request"
    _method: str = "POST"
    _consumes: List[str] = ["application/x-www-form-urlencoded"]
    _produces: List[str] = ["application/json"]
    _securities: List[List[str]] = [["BEARER_AUTH"]]
    _location_query: str = None

    client_id: str  # REQUIRED in [form_data]
    namespace: str  # REQUIRED in [path]
    code_challenge: str  # OPTIONAL in [query]
    code_challenge_method: Union[str, CodeChallengeMethodEnum]  # OPTIONAL in [query]

    # endregion fields

    # region properties

    @property
    def url(self) -> str:
        return self._url

    @property
    def method(self) -> str:
        return self._method

    @property
    def consumes(self) -> List[str]:
        return self._consumes

    @property
    def produces(self) -> List[str]:
        return self._produces

    @property
    def securities(self) -> List[List[str]]:
        return self._securities

    @property
    def location_query(self) -> str:
        return self._location_query

    # endregion properties

    # region get methods

    # endregion get methods

    # region get_x_params methods

    def get_all_params(self) -> dict:
        return {
            "form_data": self.get_form_data_params(),
            "path": self.get_path_params(),
            "query": self.get_query_params(),
        }

    def get_form_data_params(self) -> dict:
        result = {}
        if hasattr(self, "client_id"):
            result["client_id"] = self.client_id
        return result

    def get_path_params(self) -> dict:
        result = {}
        if hasattr(self, "namespace"):
            result["namespace"] = self.namespace
        return result

    def get_query_params(self) -> dict:
        result = {}
        if hasattr(self, "code_challenge"):
            result["code_challenge"] = self.code_challenge
        if hasattr(self, "code_challenge_method"):
            result["code_challenge_method"] = self.code_challenge_method
        return result

    # endregion get_x_params methods

    # region is/has methods

    # endregion is/has methods

    # region with_x methods

    def with_client_id(self, value: str) -> RequestTokenExchangeCodeV3:
        self.client_id = value
        return self

    def with_namespace(self, value: str) -> RequestTokenExchangeCodeV3:
        self.namespace = value
        return self

    def with_code_challenge(self, value: str) -> RequestTokenExchangeCodeV3:
        self.code_challenge = value
        return self

    def with_code_challenge_method(
        self, value: Union[str, CodeChallengeMethodEnum]
    ) -> RequestTokenExchangeCodeV3:
        self.code_challenge_method = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "client_id") and self.client_id:
            result["client_id"] = str(self.client_id)
        elif include_empty:
            result["client_id"] = ""
        if hasattr(self, "namespace") and self.namespace:
            result["namespace"] = str(self.namespace)
        elif include_empty:
            result["namespace"] = ""
        if hasattr(self, "code_challenge") and self.code_challenge:
            result["code_challenge"] = str(self.code_challenge)
        elif include_empty:
            result["code_challenge"] = ""
        if hasattr(self, "code_challenge_method") and self.code_challenge_method:
            result["code_challenge_method"] = str(self.code_challenge_method)
        elif include_empty:
            result["code_challenge_method"] = Union[str, CodeChallengeMethodEnum]()
        return result

    # endregion to methods

    # region response methods

    # noinspection PyMethodMayBeStatic
    def parse_response(
        self, code: int, content_type: str, content: Any
    ) -> Tuple[
        Union[None, OauthmodelTargetTokenCodeResponse], Union[None, HttpResponse]
    ]:
        """Parse the given response.

        200: OK - OauthmodelTargetTokenCodeResponse (Succeed to request token exchange code.)

        ---: HttpResponse (Undocumented Response)

        ---: HttpResponse (Unexpected Content-Type Error)

        ---: HttpResponse (Unhandled Error)
        """
        pre_processed_response, error = self.pre_process_response(
            code=code, content_type=content_type, content=content
        )
        if error is not None:
            return None, None if error.is_no_content() else error
        code, content_type, content = pre_processed_response

        if code == 200:
            return OauthmodelTargetTokenCodeResponse.create_from_dict(content), None

        return self.handle_undocumented_response(
            code=code, content_type=content_type, content=content
        )

    # endregion response methods

    # region static methods

    @classmethod
    def create(
        cls,
        client_id: str,
        namespace: str,
        code_challenge: Optional[str] = None,
        code_challenge_method: Optional[Union[str, CodeChallengeMethodEnum]] = None,
        **kwargs,
    ) -> RequestTokenExchangeCodeV3:
        instance = cls()
        instance.client_id = client_id
        instance.namespace = namespace
        if code_challenge is not None:
            instance.code_challenge = code_challenge
        if code_challenge_method is not None:
            instance.code_challenge_method = code_challenge_method
        if x_flight_id := kwargs.get("x_flight_id", None):
            instance.x_flight_id = x_flight_id
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> RequestTokenExchangeCodeV3:
        instance = cls()
        if "client_id" in dict_ and dict_["client_id"] is not None:
            instance.client_id = str(dict_["client_id"])
        elif include_empty:
            instance.client_id = ""
        if "namespace" in dict_ and dict_["namespace"] is not None:
            instance.namespace = str(dict_["namespace"])
        elif include_empty:
            instance.namespace = ""
        if "code_challenge" in dict_ and dict_["code_challenge"] is not None:
            instance.code_challenge = str(dict_["code_challenge"])
        elif include_empty:
            instance.code_challenge = ""
        if (
            "code_challenge_method" in dict_
            and dict_["code_challenge_method"] is not None
        ):
            instance.code_challenge_method = str(dict_["code_challenge_method"])
        elif include_empty:
            instance.code_challenge_method = Union[str, CodeChallengeMethodEnum]()
        return instance

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "client_id": "client_id",
            "namespace": "namespace",
            "code_challenge": "code_challenge",
            "code_challenge_method": "code_challenge_method",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "client_id": True,
            "namespace": True,
            "code_challenge": False,
            "code_challenge_method": False,
        }

    @staticmethod
    def get_enum_map() -> Dict[str, List[Any]]:
        return {
            "code_challenge_method": ["S256", "plain"],  # in query
        }

    # endregion static methods



# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
import json
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import WebSocketMessage

from ....core import WebSocketMessageParserError

from ....core import WebSocketMessageParserException
from ....core import generate_websocket_message_id


class DsNotif(WebSocketMessage):
    # region fields

    alternate_ips: List[str]
    custom_attribute: str
    deployment: str
    game_version: str
    image_version: str
    ip: str
    is_ok: bool
    is_override_game_version: bool
    last_update: str
    match_id: str
    message: str
    namespace: str
    pod_name: str
    port: int
    ports: Dict[str, int]
    protocol: str
    provider: str
    region: str
    session_id: str
    status: str

    # endregion fields

    # region methods

    # noinspection PyMethodMayBeStatic
    def to_wsm(self) -> str:
        # pylint: disable=no-self-use
        wsm = [f"type: {DsNotif.get_type()}"]
        if hasattr(self, "alternate_ips") and self.alternate_ips:
            wsm.append(
                f"alternateIps: ["
                + ",".join([str(i) for i in self.alternate_ips])
                + "]"
            )
        if hasattr(self, "custom_attribute") and self.custom_attribute:
            wsm.append(f"customAttribute: {self.custom_attribute}")
        if hasattr(self, "deployment") and self.deployment:
            wsm.append(f"deployment: {self.deployment}")
        if hasattr(self, "game_version") and self.game_version:
            wsm.append(f"gameVersion: {self.game_version}")
        if hasattr(self, "image_version") and self.image_version:
            wsm.append(f"imageVersion: {self.image_version}")
        if hasattr(self, "ip") and self.ip:
            wsm.append(f"ip: {self.ip}")
        if hasattr(self, "is_ok") and self.is_ok:
            wsm.append(f"isOK: {self.is_ok}")
        if hasattr(self, "is_override_game_version") and self.is_override_game_version:
            wsm.append(f"isOverrideGameVersion: {self.is_override_game_version}")
        if hasattr(self, "last_update") and self.last_update:
            wsm.append(f"lastUpdate: {self.last_update}")
        if hasattr(self, "match_id") and self.match_id:
            wsm.append(f"matchId: {self.match_id}")
        if hasattr(self, "message") and self.message:
            wsm.append(f"message: {self.message}")
        if hasattr(self, "namespace") and self.namespace:
            wsm.append(f"namespace: {self.namespace}")
        if hasattr(self, "pod_name") and self.pod_name:
            wsm.append(f"podName: {self.pod_name}")
        if hasattr(self, "port") and self.port:
            wsm.append(f"port: {self.port}")
        if hasattr(self, "ports") and self.ports:
            wsm.append(f"ports: {json.dumps(self.ports)}")
        if hasattr(self, "protocol") and self.protocol:
            wsm.append(f"protocol: {self.protocol}")
        if hasattr(self, "provider") and self.provider:
            wsm.append(f"provider: {self.provider}")
        if hasattr(self, "region") and self.region:
            wsm.append(f"region: {self.region}")
        if hasattr(self, "session_id") and self.session_id:
            wsm.append(f"sessionId: {self.session_id}")
        if hasattr(self, "status") and self.status:
            wsm.append(f"status: {self.status}")
        return "\n".join(wsm)

    # endregion methods

    # region static methods

    @classmethod
    def create_from_wsm(cls, wsm: str, is_strict: bool = False) -> DsNotif:
        instance = cls()
        if not wsm:
            return instance
        lines = wsm.splitlines(keepends=False)
        if len(lines) < 1:
            raise WebSocketMessageParserException(
                WebSocketMessageParserError.TypeFormatInvalid
            )
        for line in lines[1:]:
            parts = line.split(":", 1)
            if len(parts) != 2:
                raise WebSocketMessageParserException(
                    WebSocketMessageParserError.FieldFormatInvalid
                )
            name, value = parts[0].strip(), parts[1].strip()
            if (not is_strict and name.casefold() == "alternateIps".casefold()) or (
                name == "alternateIps"
            ):
                instance.alternate_ips = [
                    str(i) for i in value.removeprefix("[").removesuffix("]").split(",")
                ]
                continue
            if (not is_strict and name.casefold() == "customAttribute".casefold()) or (
                name == "customAttribute"
            ):
                instance.custom_attribute = value
                continue
            if (not is_strict and name.casefold() == "deployment".casefold()) or (
                name == "deployment"
            ):
                instance.deployment = value
                continue
            if (not is_strict and name.casefold() == "gameVersion".casefold()) or (
                name == "gameVersion"
            ):
                instance.game_version = value
                continue
            if (not is_strict and name.casefold() == "imageVersion".casefold()) or (
                name == "imageVersion"
            ):
                instance.image_version = value
                continue
            if (not is_strict and name.casefold() == "ip".casefold()) or (name == "ip"):
                instance.ip = value
                continue
            if (not is_strict and name.casefold() == "isOK".casefold()) or (
                name == "isOK"
            ):
                instance.is_ok = value
                continue
            if (
                not is_strict and name.casefold() == "isOverrideGameVersion".casefold()
            ) or (name == "isOverrideGameVersion"):
                instance.is_override_game_version = value
                continue
            if (not is_strict and name.casefold() == "lastUpdate".casefold()) or (
                name == "lastUpdate"
            ):
                instance.last_update = value
                continue
            if (not is_strict and name.casefold() == "matchId".casefold()) or (
                name == "matchId"
            ):
                instance.match_id = value
                continue
            if (not is_strict and name.casefold() == "message".casefold()) or (
                name == "message"
            ):
                instance.message = value
                continue
            if (not is_strict and name.casefold() == "namespace".casefold()) or (
                name == "namespace"
            ):
                instance.namespace = value
                continue
            if (not is_strict and name.casefold() == "podName".casefold()) or (
                name == "podName"
            ):
                instance.pod_name = value
                continue
            if (not is_strict and name.casefold() == "port".casefold()) or (
                name == "port"
            ):
                instance.port = value
                continue
            if (not is_strict and name.casefold() == "ports".casefold()) or (
                name == "ports"
            ):
                instance.ports = json.loads(value)
                continue
            if (not is_strict and name.casefold() == "protocol".casefold()) or (
                name == "protocol"
            ):
                instance.protocol = value
                continue
            if (not is_strict and name.casefold() == "provider".casefold()) or (
                name == "provider"
            ):
                instance.provider = value
                continue
            if (not is_strict and name.casefold() == "region".casefold()) or (
                name == "region"
            ):
                instance.region = value
                continue
            if (not is_strict and name.casefold() == "sessionId".casefold()) or (
                name == "sessionId"
            ):
                instance.session_id = value
                continue
            if (not is_strict and name.casefold() == "status".casefold()) or (
                name == "status"
            ):
                instance.status = value
                continue
            if is_strict:
                raise WebSocketMessageParserException(
                    WebSocketMessageParserError.FieldTypeNotSupported
                )
        return instance

    @staticmethod
    def get_type() -> str:
        return "dsNotif"

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "alternateIps": "alternate_ips",
            "customAttribute": "custom_attribute",
            "deployment": "deployment",
            "gameVersion": "game_version",
            "imageVersion": "image_version",
            "ip": "ip",
            "isOK": "is_ok",
            "isOverrideGameVersion": "is_override_game_version",
            "lastUpdate": "last_update",
            "matchId": "match_id",
            "message": "message",
            "namespace": "namespace",
            "podName": "pod_name",
            "port": "port",
            "ports": "ports",
            "protocol": "protocol",
            "provider": "provider",
            "region": "region",
            "sessionId": "session_id",
            "status": "status",
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as


from ..operations.fleet_commander import BasicHealthCheck
from ..operations.fleet_commander import Func1
from ..operations.fleet_commander import PortalHealthCheck


@same_doc_as(BasicHealthCheck)
def basic_health_check(x_additional_headers: Optional[Dict[str, str]] = None, **kwargs):
    """Health check (BasicHealthCheck)

    Properties:
        url: /healthz

        method: GET

        tags: ["Fleet Commander"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

    Responses:
        200: OK - (OK)
    """
    request = BasicHealthCheck.create()
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(BasicHealthCheck)
async def basic_health_check_async(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """Health check (BasicHealthCheck)

    Properties:
        url: /healthz

        method: GET

        tags: ["Fleet Commander"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

    Responses:
        200: OK - (OK)
    """
    request = BasicHealthCheck.create()
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(Func1)
def func1(x_additional_headers: Optional[Dict[str, str]] = None, **kwargs):
    """Version info (func1)

    Properties:
        url: /ams/version

        method: GET

        tags: ["Fleet Commander"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

    Responses:
        200: OK - (OK)
    """
    request = Func1.create()
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(Func1)
async def func1_async(x_additional_headers: Optional[Dict[str, str]] = None, **kwargs):
    """Version info (func1)

    Properties:
        url: /ams/version

        method: GET

        tags: ["Fleet Commander"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

    Responses:
        200: OK - (OK)
    """
    request = Func1.create()
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PortalHealthCheck)
def portal_health_check(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """Health check (PortalHealthCheck)

    Properties:
        url: /ams/healthz

        method: GET

        tags: ["Fleet Commander"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

    Responses:
        200: OK - (OK)
    """
    request = PortalHealthCheck.create()
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PortalHealthCheck)
async def portal_health_check_async(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """Health check (PortalHealthCheck)

    Properties:
        url: /ams/healthz

        method: GET

        tags: ["Fleet Commander"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

    Responses:
        200: OK - (OK)
    """
    request = PortalHealthCheck.create()
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )
